'use client'
'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _tslib = require('../../../../_virtual/_tslib.cjs');
var viem = require('viem');
var utils = require('@dynamic-labs/utils');
var isTransactionExecutionError = require('../isTransactionExecutionError/isTransactionExecutionError.cjs');

const interceptTransport = ({ getAccounts, onPersonalSign, onSendTransaction, onSignTypedData, onGetCapabilities, onSendCalls, transport, }) => (props) => {
    const provider = transport(props);
    return viem.custom({
        request: (args) => _tslib.__awaiter(void 0, void 0, void 0, function* () {
            var _a;
            const { method, params } = args;
            if (getAccounts && method === 'eth_accounts') {
                return getAccounts({ provider });
            }
            if (onPersonalSign && method === 'personal_sign') {
                const [message] = params;
                return onPersonalSign({ args, message, provider }).catch((error) => {
                    if (error instanceof utils.UserRejectedRequestError) {
                        throw new viem.UserRejectedRequestError(error);
                    }
                    throw error;
                });
            }
            if (onSendTransaction && method === 'eth_sendTransaction') {
                const [transaction] = params;
                return onSendTransaction({ args, provider, transaction }).catch((error) => {
                    if (isTransactionExecutionError.isTransactionExecutionError(error) &&
                        error.walk() instanceof utils.UserRejectedTransactionError) {
                        throw new viem.UserRejectedRequestError(error.walk());
                    }
                    if (error instanceof utils.UserRejectedTransactionError) {
                        throw new viem.UserRejectedRequestError(error);
                    }
                    if (error instanceof utils.UserRejectedRequestError) {
                        throw new viem.UserRejectedRequestError(error);
                    }
                    throw error;
                });
            }
            if (onSignTypedData && method === 'eth_signTypedData_v4') {
                const [, message] = (_a = params) !== null && _a !== void 0 ? _a : [];
                return onSignTypedData({ args, message, provider }).catch((error) => {
                    if (error instanceof utils.UserRejectedRequestError) {
                        throw new viem.UserRejectedRequestError(error);
                    }
                    throw error;
                });
            }
            if (onGetCapabilities && method === 'wallet_getCapabilities') {
                return onGetCapabilities({ provider });
            }
            if (onSendCalls && method === 'wallet_sendCalls') {
                const [callParams] = params;
                return onSendCalls({ callParams, provider });
            }
            return provider.request(args);
        }),
    })(props);
};

exports.interceptTransport = interceptTransport;
